@@ -65,8 +65,6 @@
 #include <KCalUtils/DndFactory>
 #include <KCalUtils/Stringify>
 
-#include <KHolidays/HolidayRegion>
-
 #include <PimCommonAkonadi/CollectionAclPage>
 #include <PimCommonAkonadi/ImapAclAttribute>
 
@@ -86,8 +84,8 @@
 enum ItemActions {
     Cancel = KMessageBox::Cancel, // Do nothing.
     Current = KMessageBox::Ok, // Selected recurrence only.
-    AlsoFuture = KMessageBox::No, // Selected and future recurrences.
-    Parent = KMessageBox::Yes, // Instance, but not child instances.
+    AlsoFuture = KMessageBox::ButtonCode::SecondaryAction, // Selected and future recurrences.
+    Parent = KMessageBox::ButtonCode::PrimaryAction, // Instance, but not child instances.
     All = KMessageBox::Continue, // Instance and child instances.
 };
 
@@ -186,7 +184,10 @@ CalendarView::CalendarView(QWidget *parent)
     // Signals emitted by mDateNavigator
     connect(mDateNavigator, &DateNavigator::datesSelected, this, &CalendarView::showDates);
 
-    connect(mDateNavigatorContainer, &DateNavigatorContainer::newEventSignal, this, qOverload<const QDate &>(&CalendarView::newEvent));
+    connect(mDateNavigatorContainer, &DateNavigatorContainer::newEventSignal, this, [=](const QDate &s, const QDate &t) {
+        newEvent(QDateTime(s, QTime::currentTime()), QDateTime(t, QTime::currentTime()));
+    });
+
     connect(mDateNavigatorContainer, &DateNavigatorContainer::newTodoSignal, this, qOverload<const QDate &>(&CalendarView::newTodo));
     connect(mDateNavigatorContainer, &DateNavigatorContainer::newJournalSignal, this, qOverload<const QDate &>(&CalendarView::newJournal));
 
@@ -801,7 +802,7 @@ void CalendarView::edit_paste()
     }
 
     if (!finalDateTime.isValid() && curView->supportsDateNavigation()) {
-        KMessageBox::sorry(this, i18n("Paste failed: unable to determine a valid target date."));
+        KMessageBox::error(this, i18n("Paste failed: unable to determine a valid target date."));
         return;
     }
 
@@ -1376,7 +1377,7 @@ void CalendarView::toggleOccurrenceCompleted(const Akonadi::Item &todoItem, cons
         return;
     }
 
-    KCalendarCore::Todo::Ptr oldtodo {todo->clone()};
+    KCalendarCore::Todo::Ptr oldtodo{todo->clone()};
     toggleCompleted(todo, occurrenceDate);
     mChanger->startAtomicOperation(i18n("Toggle To-do Completed"));
     (void)mChanger->modifyIncidence(todoItem, oldtodo, this);
@@ -1495,10 +1496,9 @@ void CalendarView::moveIncidenceToResource(const Akonadi::Item &item, const Akon
         if (!oldCal || resources->deleteIncidence(incidence)) {
             KMessageBox::error(this,
                                i18nc("@info",
-                                     "Unable to remove the item \"%1\" from %2. "
-                                     "However, a copy of this item has been put into %3.",
+                                     "Unable to remove the item \"%1\" from the original calendar. "
+                                     "However, a copy of this item has been put into %2",
                                      incidence->summary(),
-                                     oldCal->resourceName(),
                                      newCal->resourceName()),
                                i18nc("@title:window", "Moving Failed"));
         } else {
@@ -1549,29 +1549,29 @@ void CalendarView::dissociateOccurrences(const Akonadi::Item &item, QDate date)
     bool doFuture = false;
 
     if (isFirstOccurrence) {
-        answer = KMessageBox::questionYesNo(this,
-                                            i18n("Do you want to dissociate "
-                                                 "the occurrence on %1 "
-                                                 "from the recurrence?",
-                                                 QLocale::system().toString(date, QLocale::LongFormat)),
-                                            i18n("KOrganizer Confirmation"),
-                                            KGuiItem(i18n("&Dissociate")),
-                                            KStandardGuiItem::cancel());
+        answer = KMessageBox::questionTwoActions(this,
+                                                 i18n("Do you want to dissociate "
+                                                      "the occurrence on %1 "
+                                                      "from the recurrence?",
+                                                      QLocale::system().toString(date, QLocale::LongFormat)),
+                                                 i18n("KOrganizer Confirmation"),
+                                                 KGuiItem(i18n("&Dissociate")),
+                                                 KStandardGuiItem::cancel());
 
-        doOnlyThis = (answer == KMessageBox::Yes);
+        doOnlyThis = (answer == KMessageBox::ButtonCode::PrimaryAction);
     } else {
-        answer = KMessageBox::questionYesNoCancel(this,
-                                                  i18n("Do you want to dissociate "
-                                                       "the occurrence on %1 "
-                                                       "from the recurrence or also "
-                                                       "dissociate future ones?",
-                                                       QLocale::system().toString(date, QLocale::LongFormat)),
-                                                  i18n("KOrganizer Confirmation"),
-                                                  KGuiItem(i18n("&Only Dissociate This One")),
-                                                  KGuiItem(i18n("&Also Dissociate Future Ones")));
+        answer = KMessageBox::questionTwoActionsCancel(this,
+                                                       i18n("Do you want to dissociate "
+                                                            "the occurrence on %1 "
+                                                            "from the recurrence or also "
+                                                            "dissociate future ones?",
+                                                            QLocale::system().toString(date, QLocale::LongFormat)),
+                                                       i18n("KOrganizer Confirmation"),
+                                                       KGuiItem(i18n("&Only Dissociate This One")),
+                                                       KGuiItem(i18n("&Also Dissociate Future Ones")));
 
-        doOnlyThis = (answer == KMessageBox::Yes);
-        doFuture = (answer == KMessageBox::No);
+        doOnlyThis = (answer == KMessageBox::ButtonCode::PrimaryAction);
+        doFuture = (answer == KMessageBox::ButtonCode::SecondaryAction);
     }
 
     if (doOnlyThis) {
@@ -1595,9 +1595,9 @@ void CalendarView::dissociateOccurrence(const Akonadi::Item &item, const QDateTi
         (void)mChanger->createIncidence(newInc, item.parentCollection(), this);
     } else {
         if (thisAndFuture) {
-            KMessageBox::sorry(this, i18n("Dissociating the future occurrences failed."), i18n("Dissociating Failed"));
+            KMessageBox::error(this, i18n("Dissociating the future occurrences failed."), i18n("Dissociating Failed"));
         } else {
-            KMessageBox::sorry(this, i18n("Dissociating the occurrence failed."), i18n("Dissociating Failed"));
+            KMessageBox::error(this, i18n("Dissociating the occurrence failed."), i18n("Dissociating Failed"));
         }
     }
     endMultiModify();
@@ -2215,17 +2215,17 @@ int CalendarView::questionIndependentChildren(const Akonadi::Item &item)
     int km;
     auto incidence = Akonadi::CalendarUtils::incidence(item);
     if (!incidence->hasRecurrenceId() && !mCalendar->childItems(item.id()).isEmpty()) {
-        km = KMessageBox::questionYesNoCancel(this,
-                                              i18n("The item \"%1\" has sub-to-dos. "
-                                                   "Do you want to delete just this item and "
-                                                   "make all its sub-to-dos independent, or "
-                                                   "delete the to-do with all its sub-to-dos?",
-                                                   incidence->summary()),
-                                              i18n("KOrganizer Confirmation"),
-                                              KGuiItem(i18n("Delete Only This")),
-                                              KGuiItem(i18n("Delete All")));
+        km = KMessageBox::questionTwoActionsCancel(this,
+                                                   i18n("The item \"%1\" has sub-to-dos. "
+                                                        "Do you want to delete just this item and "
+                                                        "make all its sub-to-dos independent, or "
+                                                        "delete the to-do with all its sub-to-dos?",
+                                                        incidence->summary()),
+                                                   i18n("KOrganizer Confirmation"),
+                                                   KGuiItem(i18n("Delete Only This")),
+                                                   KGuiItem(i18n("Delete All")));
 
-        if (km == KMessageBox::No) {
+        if (km == KMessageBox::ButtonCode::SecondaryAction) {
             km = KMessageBox::Continue;
         }
     } else {
@@ -2403,7 +2403,7 @@ void CalendarView::warningChangeFailed(const Akonadi::Item &item)
 {
     KCalendarCore::Incidence::Ptr incidence = Akonadi::CalendarUtils::incidence(item);
     if (incidence) {
-        KMessageBox::sorry(this, i18nc("@info", "Unable to edit \"%1\" because it is locked by another process.", incidence->summary()));
+        KMessageBox::error(this, i18nc("@info", "Unable to edit \"%1\" because it is locked by another process.", incidence->summary()));
     }
 }
 
@@ -2415,7 +2415,7 @@ void CalendarView::showErrorMessage(const QString &msg)
 void CalendarView::addIncidenceOn(const Akonadi::Item &itemadd, const QDate &dt)
 {
     if (!CalendarSupport::hasIncidence(itemadd)) {
-        KMessageBox::sorry(this, i18n("Unable to copy the item to %1.", dt.toString()), i18n("Copying Failed"));
+        KMessageBox::error(this, i18n("Unable to copy the item to %1.", dt.toString()), i18n("Copying Failed"));
         return;
     }
     Akonadi::Item item = mCalendar->item(itemadd.id());
@@ -2450,7 +2450,7 @@ void CalendarView::addIncidenceOn(const Akonadi::Item &itemadd, const QDate &dt)
 void CalendarView::moveIncidenceTo(const Akonadi::Item &itemmove, QDate dt)
 {
     if (!CalendarSupport::hasIncidence(itemmove)) {
-        KMessageBox::sorry(this, i18n("Unable to move the item to  %1.", dt.toString()), i18n("Moving Failed"));
+        KMessageBox::error(this, i18n("Unable to move the item to  %1.", dt.toString()), i18n("Moving Failed"));
         return;
     }
     Akonadi::Item item = mCalendar->item(itemmove.id());
